@@ -28,6 +28,8 @@ c              save the initial seed of random number
             call rnd1s(SeedSave)
             if(Job .eq. 'skeleton') then
                call cwriteSeed
+            elseif(Job .ne. 'flesh' .and. SeedFile .ne. ' ') then
+               call cwriteSeed
             endif
          endif            
          call cmkIncident(incident)
@@ -73,3 +75,16 @@ c          read iformation for initial random number at flesh time
 
       read(SeedFileDev, *) ir, no
       end
+c      inquire the event number
+      subroutine cqEventNo(num, cumnum)
+      implicit none
+#include "Zmanagerp.h"      
+      integer num   ! output. number of events in the current run
+      integer cumnum ! output. cummulative number of events so far.
+c     may be used  after the initialization of an event, then
+c     this gives the number for that event.
+c      
+
+      num = EventsInTheRun
+      cumnum = EventNo
+      end
