@@ -1,3 +1,4 @@
+#include "chookHybAS.f"
 #include "ctemplCeren.f"
 #include "ZcosmosBD.h"
 c  *************************************** hook for Beginning of a Run
@@ -8,19 +9,18 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
-#include "Zcoord.h"
-#include "Zpos.h"
-#include "Zmagfield.h"
-#include  "Zobs.h"
-#include  "Zobsp.h"
-#include  "Zobsv.h"
-#include  "Ztrackp.h"
-
 
 c          ///////////
-      common /testcos/sumg, ng, nth, nev, nec(12)
-      real*8 sumg
-      integer ng, nth, nev, nec
+      common /debug/ sw
+      logical sw
+
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth
 c     //////////////
 
 c         If you feel writing the parameters on stderr is
@@ -33,22 +33,31 @@ c         Also you may comment out all output routines below.
 
       ieeer = ieee_handler('set', 'invalid', csigHandler)
 #endif
-       integer i
+
+      sw = .false.
 c
 c            namelist output
-
-        call cwriteParam(ErrorOut, 0)
-
+      call cwriteParam(ErrorOut, 0)
 c            primary information
       call cprintPrim(ErrorOut)
 c            observation level information
       call cprintObs(ErrorOut)
-      nth = 0
-      nev = 0
-      do i = 1, NoOfSites
-         nec(i) =0
-      enddo
-      open(TraceDev, file='/tmp/cheren')
+
+      eth(1) = 0.3d-3
+      eth(2) = 0.5d-3
+      eth(3)=  1.d-3
+      eth(4) = 2.d-3
+      eth(5) = 5.d-3
+      eth(6) = 10.d-3
+      eth(7) = 20.d-3
+      eth(8)=  50.d-3
+      eth(9) = 100.d-3
+      eth(10) = 200.d-3
+      eth(11) = 500.d-3
+      eth(12) = 1.d0
+c      ////////////
+      ntha = 1  !  for each ptcle out put use only 1 threshold
+c     /////////////
       end
 #ifdef sun4
       integer function csigHandler(sig, code, context)
@@ -67,30 +76,70 @@ c     *  After this is executed, event generation starts.
 c     *
       subroutine chookBgEvent
       implicit none
-c          ///////////
 #include "Ztrack.h"
-      common /testcos/sumg, ng, nth, nev, nec(12)
-      real*8 sumg
-      integer ng, nth, nev, nec
-      integer  remain
-      record /track/ aT
+#include "Zmanagerp.h"
+
+c          ///////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth
 c     //////////////
+
+
+
+
+      record /track/ inci
+      record /coord/ angle
+
+      integer  nev
+c     //////////////
+      integer i, j
       integer seed(2)
 c      write(*, *) ' bigin event generation'
-      call cqIniRn(seed)
-c      write(*,*) ' seed=', seed
-      sumg = 0.
-      ng = 0
-      nev = nev + 1
-c      call cpop(aT, remain)
-c         make 4 proton beams; for check He and  4 protons
-c      call cpush(aT)
-c      call cpush(aT)
-c      call cpush(aT)
-c      call cpush(aT)
+c      call cqIniRn(seed)
+c      write(ErrorOut,*)  seed, EventNo
+c      call cwriteSeed
+      do i = 1, nl
+         do j = 1, ntha
+            ng(j, i) = 0
+            ne(j, i) = 0
+            nh(j, i) = 0
+            nmu(j, i) = 0
+         enddo
+      enddo
+      write(*, *)
+      call cqIncident(inci, angle)
+      write(*,'(i7,i4,g13.4,3f10.7)') EventNo, inci.p.code, inci.p.fm.e,
+     *  -angle.r(1),  -angle.r(2), -angle.r(3)      
       end
-  
+      subroutine ccount(nc, aTrack)
+      implicit none
+#include "Zcode.h"
+#include "Ztrack.h"
 
+      record /track/ aTrack
+      integer i
+c          ///////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl),
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth
+c
+      integer nc(nth, nl)
+
+      do i = 1, ntha
+        if( aTrack.p.fm.e- aTrack.p.mass .lt. eth(i)) goto 10
+        nc(i, aTrack.where) =  nc(i, aTrack.where) + 1
+      enddo
+ 10   continue 
+      end
 c     ************************************ hook for observation
 c     *  One particel information is brought here by the system.
 c     *  All information of the particle is in aTrack
@@ -105,39 +154,98 @@ c
       implicit none
 #include "Zcode.h"
 #include "Ztrack.h"
+#include  "Zheavyp.h"
       integer id  ! input.  1 ==> aTrack is going out from
 c                                 outer boundery.
 c                           2 ==> reached at an observation level
 c                           3 ==> reached at inner boundery.
       record /track/ aTrack
+      record /track/ inci
+      record /coord/ angle, tetafai
+c      integer i
 c          ///////////
-      common /testcos/sumg, ng, nth, nev, nec(12)
-      real*8 sumg
-      integer ng, nth, nev, nec
+      common /debug/ sw
+      logical sw
+
+c          ///////////
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth
 c     //////////////
 
+      integer iij
+      real*8 r
+
+
 c
 c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
-c      if(aTrack.p.code .eq. kmuon) then
+c      if(id .eq. 2 .and. aTrack.p.code .eq. kmuon ) then
+       if( id .eq. 2) then
+           iij = aTrack.p.code  
+c          call cgpid(iij, ptclid)
+           if(iij .eq. kelec ) then
+c     call cqIncident(inci, angle)
+              call ccount(ne, aTrack)
+c              ne(aTrack.where) = ne(aTrack.where) + 1
+           elseif(iij  .eq. kphoton ) then
+              call ccount(ng, aTrack)
+c              ng(aTrack.where) = ng(aTrack.where) + 1
+           elseif(iij .eq. kmuon ) then
+              call ccount(nmu, aTrack)
+c              nmu(aTrack.where) = nmu(aTrack.where) + 1
+           elseif( iij .eq. kpion  .or. iij .eq.  kkaon .or. 
+     *        iij .eq. knuc) then
+              if(aTrack.p.charge .ne. 0 ) then
+                 call ccount(nh, aTrack)
+c                 nh(aTrack.where) = nh(aTrack.where) + 1
+              endif
+           endif
+        endif
+        if(aTrack.p.code .eq. kmuon) then
+c////////
+c              if(abs(aTrack.p.fm.e - 2.73879529405316d0)
+c     *             .lt. 1.d-10) then
+c                 sw =.true.
+c                 write(*, *) ' sw on ------------------------'
+c              endif
+c///////////
+           r = sqrt(aTrack.pos.xyz.x**2 + aTrack.pos.xyz.y**2)
+           write(*,*) aTrack.where, sngl(r), aTrack.p.fm.e
+        endif
 c            output typical quantities.
-c        write(*, *)   id, 
-c         write(*,*)
+c         id .eq. 2 below  if want otuput
+c        if(id .eq. 2 .and. aTrack.where .eq.  8 ) then
+c         if(aTrack.p.code .ne. kneue .and. aTrack.p.code .ne. 
+c     *    kneumu) then
+c       write(*, *)
+c     *  '(i2,1x,i2,1x,f12.2, g13.4, f12.2,1x, f12.2,1x,f7.4,i3)')
+c     * nev, 
 c     *  aTrack.where,   !  observation level. integer*2.  1 is highest.
-c     *  aTrack.p.code,    !  ptcl code.  integer*2.
+c     *  aTrack.p.code,  ! " ", ptclid,    !  ptcl code.  integer*2.
 c     *  aTrack.p.charge,  !  charge,  integer*2 
-cc                        !  if TimeStructure is F, nonsense.
-c     *  sngl(aTrack.p.fm.e),  ! total energy in GeV.
-c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y) !  x, y in m
-c     *  sngl(aTrack.t)  !  relateive arrival time in nsec (NOT sec).
-c    *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
+c     *  sngl(aTrack.t), !  relateive arrival time in nsec (NOT sec).
+c                        !  if TimeStructure is F, nonsense.
+c     *  sngl(aTrack.p.fm.e), !  - aTrack.p.mass), ! kinetic energy in GeV
+c     *  sngl(aTrack.pos.xyz.x), sngl(aTrack.pos.xyz.y),  !  x, y in m
+c     *  sngl(aTrack.vec.w.x),  ! direc. cos.x in the current detector system.
 c     *  sngl(aTrack.vec.w.y),  ! direc. cos.y
 c     *  sngl(aTrack.vec.w.z),  ! direc. cos.z
-c     *  sngl(aTrack.vec.coszenith) ! cos of zenith angle
+c     * sngl(-angle.r(3)) ,
+c     * sngl(aTrack.vec.coszenith)  ! cos of zenith angle
+c     * sngl(inci.p.fm.p(4)-inci.p.mass)/Code2massN(int(inci.p.code)),
+c     * inci.p.code
+c         if(aTrack.p.code .eq. kelec) then
+c            write(*, *) aTrack.where
+c         endif
 c      endif
 c         you may need in some case other information such as
-c       aTrack.p.subcode   ! sub code of the particle integer*2
+c     *  aTrack.p.subcode   ! sub code of the particle integer*2
 c       aTrack.p.mass      ! mass 
 c       aTrack.wgt         ! weight of the particle (may not be 1. if
 c                           ! ThinSampling =T)
@@ -147,9 +255,12 @@ c                            given in the  Earth xyz system.
 c       aTrack.p.fm.y      !          y
 c       aTrack.p.fm.z      !          z
 c        if(aTrack.p.code .eq. kelec .or. aTrack.p.code .eq. kphoton) 
-c        if(aTrack.p.code .eq. kelec ) then
-c           nec(aTrack.where) = nec(aTrack.where) + 1
+c     *     then
+c           ng = ng+1
+c           sumg = sumg + aTrack.p.fm.e
+c
 c        endif
+c      endif
       end
 
 c    *********************************** hook for end of 1 event
@@ -167,30 +278,65 @@ c    *
 
 
 
-      integer i
+      record /track/ inci
+      record /coord/ angle, tetafai
+      integer i, j
+
 c          ///////////
-      common /testcos/sumg, ng, nth, nev, nec(12)
-      real*8 sumg
-      integer ng, nth, nev, nec
+      integer nl, nth
+      parameter (nl = 20, nth=12)
+      common /testcos/eth(nth),
+     * ng(nth, nl), ne(nth, nl), nmu(nth, nl), 
+     * nh(nth, nl), ntha
+      integer ng, ne, nmu, nh, ntha
+      real*8 eth
 c     //////////////
 
+
+
+c          ///////////
+      real*8  fdepth, bsin, teta, fai, sumsize
+      real*8  cgetBsin
+c     //////////////
+c      call cqIncident(inci, angle)
+c      write(*,*) inci.vec.coszenith, angle.r(3)
       if(ObserveAS) then
+         call cqFirstID(fdepth)
+         fdepth = fdepth * 0.1         ! in g/cm2
+         call cqIncident(inci, angle)
+         angle.r(1) = -angle.r(1)   ! angle is directed to downward
+         angle.r(2) = -angle.r(2)
+         angle.r(3) = -angle.r(3)
+         call ceCent2sph(angle, tetafai)
+         teta = tetafai.r(1) 
+         fai = tetafai.r(2)
+         if(fai  .lt. 0. ) fai = 360.d0+fai
+         bsin = cgetBsin(inci.p, Mag)*1.e4
 c                   electron size in B approx.
-         do i = 1, NoOfASSites
-            write(*, *) sngl(ASObsSites(i).pos.depth), 
-     *      sngl(ASObsSites(i).esize), i
-         enddo
+c         write(*, *) (ASObsSites(i).esize, i=1, NoOfASSites)
 c                   size weighted age
 c         write(*, *) (ASObsSites(i).age,   i=1, NoOfASSites) 
+         sumsize = 0.
+         write(*, *)
+        do j = 1, ntha
+          if(ntha .gt. 1) then
+c             write(*,*) j
+          endif
+           do i = 1, NoOfASSites
+              sumsize = sumsize + ASObsSites(i).esize
+c               write(*, '(f7.1,g13.3,f8.3,f7.1,
+c     *             4i8,f7.4)')
+c     *       f8.3,    g13.3,f10.3,f10.3) ')
+c     *           sngl(ASObsSites(i).pos.depth/10./angle.r(3)),
+c     *           sngl(ASObsSites(i).pos.depth/10.),
+c     *           sngl(ASObsSites(i).esize), 
+c     *           sngl(ASObsSites(i).age), sngl(fdepth),
+c     *           sngl(bsin), sngl(sumsize), sngl(teta), sngl(fai)  
+c     *           ne(j, i), nmu(j, i), nh(j, i), ng(j, i), eth(j)
+            enddo
+         enddo
       endif
-c      if(ng .ge. 5 .and. sumg .ge.  10.e3) then
-c         nth = nth + 1
-c         write(*, *) ' #=', nth, ' ng, sumg=', ng, sumg, ' ev=',nev
-c      endif
-c      write(*, *) 
-c      do i = 1, NoOfSites
-c         write(*, *) nec(i)
-c      enddo
+c      write(*, *)
       end
 
 
@@ -200,35 +346,13 @@ c     *
       subroutine chookEnRun
 
       implicit none
-#include "Zcoord.h"
-#include "Zpos.h"
-#include "Zmagfield.h"
-
-#include  "Zobs.h"
-#include  "Zobsp.h"
-#include  "Zobsv.h"
-
-
-c          ///////////
-      common /testcos/sumg, ng, nth, nev, nec(12)
-      real*8 sumg
-      integer ng, nth, nev, nec
-c     //////////////
-
-       integer ntot, i
-
-        call cqNoOfPrim(ntot)
-
-c      do i = 1, NoOfSites
-c         write(*,*) nec(i)/ntot
-c      enddo
       end
 c     ********************************* hook for trace
 c     *  This is called only when trace > 100
 c     *  User should manage the trace information here.
-c     * 
-c     *  Default output for trace dev. can be used
-c     *  for each event, of which file name is trace1, trace2
+c     *  If you use this, you may need some output for trace
+c     *  at the beginning of 1 event generatio and at the end of  1 event
+c     *  generation so that you can identfy each event.
 c     *
 c     *
       subroutine chookTrace
@@ -239,12 +363,8 @@ c     *
 #include  "Ztrackp.h"
 #include  "Zobs.h"
 #include  "Zobsv.h"
-#include  "Zcode.h"
-       record /coord/ f, t
-       logical compress/.true./
-       save compress
 
-c       real*4 h1,  h2
+       real*4 h1,  h2
 c
 c    Every time a particle is moved in the atmosphere, this routine is called,
 c    if trace > 100
@@ -263,15 +383,9 @@ c     atrack.pos.depth       (vertical depth)
 c     atrack.pos.height      (vertical heigth from sea level)  
 c
 
-c      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
-c      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
-             
+      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
+      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
 
-
-      if(TrackBefMove.p.code .eq. kmuon) then
-         call ccoordForTr(Trace-100, f, t)
-         call cwrtTrInfo(compress, f, t)
-      endif
       end
 
 c     ********************* this is the hook called when
@@ -299,7 +413,7 @@ c        default setting
       never = 1
 c
 c        IntInfArray(ProcessNo).process will have one of
-c       'brems', 'mscat', 'bscat',or  'anihi'
+c       'brems', 'mscat', 'bscat', 'anihi' or 'mbrem'
 c
       end
 
@@ -327,7 +441,7 @@ c
 c        default setting
       never = 1
 c         IntInfArray(ProcessNo).process will have one of
-c        'pair', 'comp', 'photoe' or 'photop'
+c        'pair', 'comp', 'photoe' 'photop' 'mpair'
 c       
       end
 
@@ -337,8 +451,11 @@ c
       subroutine chookNEPInt(never)
             implicit none
 
+
+#include  "Zcode.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
+
 c  #include  "Ztrackp.h"
       
       integer never   ! input & output
@@ -353,10 +470,25 @@ c   Nproduced has the number of particles in Pwork
 c   IntInfArray(ProcessNo) contains the type of interaction
 c
 c        default setting
-      never = 1
+c
+c      never = 1
+        never = 1
+        if(MovedTrack.p.code .eq.  kpion .or.
+     *       MovedTrack.p.code .eq.  kkaon) then
+            if(IntInfArray(ProcessNo).process .eq. 'coll') then
+c              write(*,*)
+c     *         MovedTrack.p.code,
+c     *         sngl(MovedTrack.p.fm.p(4)), Nproduced
+           endif
+        endif
 c
 c        IntInfArray(ProcessNo).process  will have
 c             'col' or 'decay'
       end
 
       
+
+
+
+
+
