@@ -20,26 +20,10 @@ c               , clenbetween2h
       record /coord/ xyz1, xyz2, dircos, diffvec
       real*8 dummylen
 
-c
-c            see if go out of outer boundery.
-      call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
-      if(cosfromaxis .lt. BackAngLimit .or.
-     *   MovedTrack.pos.height .gt. BorderHeightH) then
-c             discard it
-         MoveStat = BorderH
-         return  !  ***************
-      endif
-c  -------------------------------------------------------------
-
-      loc = MovedTrack.where 
-      if(MovedTrack.pos.height .lt. BorderHeightL) then
-         MoveStat = BorderL
-c         leng = clenbetween2h(TrackBefMove.pos.height+Eradius,
-c     *         BorderL+Eradius, TrackBefMove.vec.coszenith)
-      endif
+      cross = .false.
       if(ObsPlane .ne. notUsed ) then
-         cross = .false.
-         if(ObsPlane .eq. horizontal) then
+         loc = MovedTrack.where 
+         if(abs(ObsPlane) .eq. horizontal) then
 c                  horizontal
             call cxyz2det(ObsSites(NoOfSites).pos.xyz, 
      *                  MovedTrack.pos.xyz, xyz2)
@@ -70,7 +54,7 @@ c                  horizontal
                   endif
                endif
             endif
-         elseif(ObsPlane .eq. perpendicular) then
+         elseif(abs(ObsPlane) .eq. perpendicular) then
 c           observation plane is perpendicular to primary
 c           convert coord into 1ry system
             call cxyz2prim(ObsSites(NoOfSites).pos.xyz, 
@@ -106,7 +90,6 @@ c           convert coord into 1ry system
             endif
          endif
 
-
          if(cross) then
             MoveStat = ToBeObserved
 c             get length, leng, from the starting point to
@@ -114,7 +97,7 @@ c             the observation depth
             call cdiffvec(TrackBefMove.pos.xyz, 
      *                    MovedTrack.pos.xyz, diffvec)
             call c3DV2DDCos(diffvec, diffvec, dummylen)
-            if(ObsPlane .eq. horizontal) then
+            if(abs(ObsPlane) .eq. horizontal) then
 c                direction cos in det system
                call cxyz2detD(diffvec, dircos)
             else
@@ -122,13 +105,18 @@ c                direction cos in 1ry system
                call cxyz2primD(diffvec, dircos)
             endif
 
-            
             leng = (ObsSites(loc).zpl - xyz1.r(3))/dircos.r(3)
+            leng = leng + abs(0.01/dircos.r(3))
+c            0.01 (=1cm) is make sure that the ptcl crosses the plane.
+c           the crossing point is made to be 1 cm apart from the real level.
+c     
 c             reset MovedTrack
             IntInfArray(ProcessNo).length = leng
             IntInfArray(ProcessNo).thickness = clen2thick(
      *      TrackBefMove.pos.radiallen - Eradius,
      *      TrackBefMove.vec.coszenith, leng)
+
+
 c
 c            call ccompPathEnd  ! this call produce some error
 c                                 on the crossing coordinate so we
@@ -136,7 +124,6 @@ c                          use straight line approximation here.
             MovedTrack = TrackBefMove
 
             call cmoveStreight(leng)
-
             if(MovedTrack.p.charge .ne. 0) then
                call cqElossRate(dedt) ! get de/dx computed previously
                MovedTrack.p.fm.p(4) =max( MovedTrack.p.fm.p(4) -
@@ -153,6 +140,25 @@ c               MovedTrack.pos.depth = ObsSites(loc).pos.depth
 c            endif
          endif
       endif
+      if(.not. cross .or. ObsPlane .eq. notUsed) then
+c
+c            see if go out of outer boundery.
+         call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
+         if(cosfromaxis .lt. BackAngLimit .or.
+     *        MovedTrack.pos.height .ge. BorderHeightH) then
+c             discard it
+            MoveStat = BorderH
+            return              !  ***************
+         endif
+c  -------------------------------------------------------------
+
+
+         if(MovedTrack.pos.height .le. BorderHeightL) then
+            MoveStat = BorderL
+c         leng = clenbetween2h(TrackBefMove.pos.height+Eradius,
+c     *         BorderL+Eradius, TrackBefMove.vec.coszenith)
+         endif
+      endif
       end
       subroutine cdiffvec(r1, r2, diff)
 c        get diff= r2-r1 as 3 D vector
