@@ -157,7 +157,8 @@ c                     capture
                   call ccapnu(TargetNucleonNo, TargetProtonNo,
      *               Pwork, Nproduced)
                else
-                  MuonPolarization = 0.   ! stopping mu has no pol.
+c!!!              MuonPolarization = 0.   ! stopping mu has no pol.
+c                                          keep the value ;it's better.
                   call cmuNeuDcy(MovedTrack.p, MuonPolarization,
      *                Pwork, Nproduced)
                endif
